[![Documentation Status](https://readthedocs.org/projects/jicket/badge/?version=stable)](https://jicket.readthedocs.io/en/stable/?badge=stable)

# Jicket

Jicket allows you to use Jira as a simple service helpdesk.
It creates new issues for incoming mails and automatically adds email replies as comments to issues.

# Documentation
You can find the documentation [here](https://jicket.readthedocs.io/en/latest/).

# Github Repository
The repo for this project can be found on [Github](https://github.com/kwp-communications/jicket).

# Contributing
See [CONTRIBUTING](CONTRIBUTING.md)

# License
MIT License, see [LICENSE](LICENSE) for the full license.